DEBUG = 0
INFO = 1
WARNING = 2
ERROR = 3
CRITICAL = 4
